@@ -13,36 +13,40 @@
 ##############################################################################
 """Test not found errors
 
-$Id: test_functional.py 107890 2010-01-08 22:36:05Z faassen $
+$Id: test_functional.py 110812 2010-04-13 16:30:31Z thefunny42 $
 """
 
 import re
 import unittest
+
 from zope.testing import renormalizing
-from zope.app.testing import functional
 from zope.app.publication.testing import PublicationLayer
+from zope.testing import doctest
 
 
 checker = renormalizing.RENormalizing([
     (re.compile(r"HTTP/1\.([01]) (\d\d\d) .*"), r"HTTP/1.\1 \2 <MESSAGE>"),
     ])
 
+optionflags = doctest.ELLIPSIS+doctest.NORMALIZE_WHITESPACE
 
 def test_suite():
-    methodnotallowed = functional.FunctionalDocFileSuite(
-        '../methodnotallowed.txt')
+    methodnotallowed = doctest.DocFileSuite(
+        '../methodnotallowed.txt',
+        optionflags=optionflags)
     methodnotallowed.layer = PublicationLayer
-    httpfactory = functional.FunctionalDocFileSuite(
-        '../httpfactory.txt', checker=checker)
+    httpfactory = doctest.DocFileSuite(
+        '../httpfactory.txt', checker=checker,
+        optionflags=optionflags)
     httpfactory.layer = PublicationLayer
-    site = functional.FunctionalDocFileSuite(
-        '../site.txt')
+    site = doctest.DocFileSuite(
+        '../site.txt',
+        optionflags=optionflags)
     site.layer = PublicationLayer
     return unittest.TestSuite((
         methodnotallowed,
         httpfactory,
-        site,
-        ))
+        site,))
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
