@@ -13,7 +13,7 @@
 ##############################################################################
 """Zope Publication Tests
 
-$Id: test_zopepublication.py 102692 2009-08-11 22:34:23Z gary $
+$Id: test_zopepublication.py 110812 2010-04-13 16:30:31Z thefunny42 $
 """
 import unittest
 import sys
@@ -24,24 +24,23 @@ from ZODB.DB import DB
 from ZODB.DemoStorage import DemoStorage
 import transaction
 
-import zope.component
 from zope.interface.verify import verifyClass
 from zope.interface import implements, classImplements, implementedBy
-from zope.i18n.interfaces import IUserPreferredCharsets
-from zope.component.interfaces import ComponentLookupError
+from zope.component.interfaces import ComponentLookupError, ISite
 from zope.error.interfaces import IErrorReportingUtility
 from zope.location import Location
 from zope.publisher.base import TestPublication, TestRequest
-from zope.publisher.http import IHTTPRequest, HTTPCharsets
 from zope.publisher.interfaces import IRequest, IPublishTraverse
 from zope.security import simplepolicies
 from zope.security.management import setSecurityPolicy, queryInteraction
 from zope.security.management import endInteraction
 from zope.traversing.interfaces import IPhysicallyLocatable
 from zope.location.interfaces import ILocation
+from zope.testing.cleanup import cleanUp
+from zope.site.site import LocalSiteManager
 
-from zope.app.testing.placelesssetup import PlacelessSetup
-from zope.app.testing import setup, ztapi
+from zope import component
+from zope.app.publication.tests import support
 
 from zope.authentication.interfaces import IAuthentication
 from zope.authentication.interfaces import IFallbackUnauthenticatedPrincipal
@@ -49,7 +48,7 @@ from zope.authentication.interfaces import IUnauthenticatedPrincipal
 from zope.security.interfaces import IPrincipal
 from zope.principalregistry.principalregistry import principalRegistry
 from zope.app.publication.zopepublication import ZopePublication
-from zope.app.folder import Folder, rootFolder
+from zope.site.folder import Folder, rootFolder
 
 
 class Principal(object):
@@ -106,28 +105,39 @@ class LocatableObject(Location):
 class TestRequest(TestRequest):
     URL='http://test.url'
 
-class BasePublicationTests(PlacelessSetup, unittest.TestCase):
+
+def addUtility(sitemanager, name, iface, utility, suffix=''):
+    """Add a utility to a site manager
+
+    This helper function is useful for tests that need to set up utilities.
+    """
+    folder_name = (name or (iface.__name__ + 'Utility')) + suffix
+    default = sitemanager['default']
+    default[folder_name] = utility
+    utility = default[folder_name]
+    sitemanager.registerUtility(utility, iface, name)
+    return utility
+
+
+class BasePublicationTests(unittest.TestCase):
 
     def setUp(self):
-        super(BasePublicationTests, self).setUp()
         from zope.security.management import endInteraction
         endInteraction()
-        ztapi.provideAdapter(IHTTPRequest, IUserPreferredCharsets,
-                             HTTPCharsets)
         self.policy = setSecurityPolicy(
             simplepolicies.PermissiveSecurityPolicy
             )
         self.storage = DemoStorage('test_storage')
         self.db = db = DB(self.storage)
 
-        ztapi.provideUtility(IAuthentication, principalRegistry)
+        component.provideUtility(principalRegistry, IAuthentication)
 
         connection = db.open()
         root = connection.root()
         app = getattr(root, ZopePublication.root_name, None)
 
         if app is None:
-            from zope.app.folder import rootFolder
+            from zope.site.folder import rootFolder
             app = rootFolder()
             root[ZopePublication.root_name] = app
             transaction.commit()
@@ -136,9 +146,10 @@ class BasePublicationTests(PlacelessSetup, unittest.TestCase):
         self.app = app
 
         from zope.traversing.namespace import view, resource, etc
-        ztapi.provideNamespaceHandler('view', view)
-        ztapi.provideNamespaceHandler('resource', resource)
-        ztapi.provideNamespaceHandler('etc', etc)
+
+        support.provideNamespaceHandler('view', view)
+        support.provideNamespaceHandler('resource', resource)
+        support.provideNamespaceHandler('etc', etc)
 
         self.request = TestRequest('/f1/f2')
         self.user = Principal('test.principal')
@@ -153,15 +164,15 @@ class BasePublicationTests(PlacelessSetup, unittest.TestCase):
         # Close the request, otherwise a Cleanup object will start logging
         # messages from its __del__ method at some inappropriate moment.
         self.request.close()
-        super(BasePublicationTests, self).tearDown()
+        cleanUp()
+
+
+class ZopePublicationErrorHandling(BasePublicationTests):
 
     def testInterfacesVerify(self):
         for interface in implementedBy(ZopePublication):
             verifyClass(interface, TestPublication)
 
-
-class ZopePublicationErrorHandling(BasePublicationTests):
-
     def testRetryAllowed(self):
         from ZODB.POSException import ConflictError
         from zope.publisher.interfaces import Retry
@@ -221,12 +232,17 @@ class ZopePublicationErrorHandling(BasePublicationTests):
         class E1(Exception):
             pass
 
-        ztapi.setDefaultViewName(E1, 'name',
-                                 layer=None,
-                                 type=self.presentation_type)
+        support.setDefaultViewName(E1, 'name',
+                                   layer=None,
+                                   type=self.presentation_type)
         view_text = 'You had a conflict error'
-        ztapi.provideView(E1, self.presentation_type, Interface,
-                          'name', lambda obj, request: lambda: view_text)
+
+        def _view(obj, request):
+            return lambda: view_text
+
+        component.provideAdapter(_view, (E1, self.presentation_type),
+                                 Interface, name='name')
+
         try:
             raise E1
         except:
@@ -263,9 +279,9 @@ class ZopePublicationErrorHandling(BasePublicationTests):
         class E2(Exception):
             pass
 
-        ztapi.setDefaultViewName(E2, 'name',
-                                 layer=self.presentation_type,
-                                 type=self.presentation_type)
+        support.setDefaultViewName(E2, 'name',
+                                   layer=self.presentation_type,
+                                   type=self.presentation_type)
         view_text = 'You had a conflict error'
 
         from zope.browser.interfaces import ISystemErrorView
@@ -280,8 +296,9 @@ class ZopePublicationErrorHandling(BasePublicationTests):
             def __call__(self):
                 return view_text
 
-        ztapi.provideView(E2, self.presentation_type, Interface,
-                          'name', MyView)
+        component.provideAdapter(MyView, (E2, self.presentation_type),
+                                 Interface, name='name')
+
         try:
             raise E2
         except:
@@ -309,10 +326,14 @@ class ZopePublicationErrorHandling(BasePublicationTests):
         class IClassicError(Interface):
             pass
         classImplements(ClassicError, IClassicError)
-        ztapi.setDefaultViewName(IClassicError, 'name', self.presentation_type)
+        support.setDefaultViewName(IClassicError, 'name',
+                                   self.presentation_type)
         view_text = 'You made a classic error ;-)'
-        ztapi.provideView(IClassicError, self.presentation_type, Interface,
-                          'name', lambda obj,request: lambda: view_text)
+        def _view(obj, request):
+            return lambda: view_text
+        component.provideAdapter(
+            _view, (ClassicError, self.presentation_type), Interface,
+            name='name')
         try:
             raise ClassicError
         except:
@@ -345,7 +366,8 @@ class ZopePublicationErrorHandling(BasePublicationTests):
         class IConflictError(Interface):
             pass
         classImplements(ConflictError, IConflictError)
-        ztapi.provideAdapter(IConflictError, IExceptionSideEffects, factory)
+        component.provideAdapter(factory, (IConflictError,),
+                                 IExceptionSideEffects)
         exception = ConflictError()
         try:
             raise exception
@@ -389,7 +411,7 @@ class ZopePublicationErrorHandling(BasePublicationTests):
 
     def testAbortTransactionWithErrorReportingUtility(self):
         # provide our fake error reporting utility
-        zope.component.provideUtility(ErrorReportingUtility())
+        component.provideUtility(ErrorReportingUtility())
 
         class FooError(Exception):
             pass
@@ -407,7 +429,7 @@ class ZopePublicationErrorHandling(BasePublicationTests):
         self.assertEqual(last_txn_info, new_txn_info)
 
         # instead, we expect a message in our logging utility
-        error_log = zope.component.getUtility(IErrorReportingUtility)
+        error_log = component.getUtility(IErrorReportingUtility)
         self.assertEqual(len(error_log.exceptions), 1)
         error_info, request = error_log.exceptions[0]
         self.assertEqual(error_info[0], FooError)
@@ -419,7 +441,7 @@ class ZopePublicationErrorHandling(BasePublicationTests):
         # been experienced) transaction.abort fails, we really want to know
         # what happened before that abort.
         # (Set up:)
-        zope.component.provideUtility(ErrorReportingUtility())
+        component.provideUtility(ErrorReportingUtility())
         abort = transaction.abort
         class AbortError(Exception):
             pass
@@ -443,7 +465,7 @@ class ZopePublicationErrorHandling(BasePublicationTests):
             else:
                 self.fail('Aborting should have failed')
             # we expect a message in our logging utility
-            error_log = zope.component.getUtility(IErrorReportingUtility)
+            error_log = component.getUtility(IErrorReportingUtility)
             self.assertEqual(len(error_log.exceptions), 1)
             error_info, request = error_log.exceptions[0]
             self.assertEqual(error_info[0], AnEarlierError)
@@ -460,7 +482,7 @@ class ZopePublicationTests(BasePublicationTests):
         # Replace the global registry with a stub that doesn't return an
         # unauthenticated principal.
         authentication = AuthUtility3()
-        ztapi.provideUtility(IAuthentication, authentication)
+        component.provideUtility(authentication, IAuthentication)
 
         # We need a fallback unauthenticated principal, otherwise we'll get a
         # ComponentLookupError:
@@ -469,56 +491,11 @@ class ZopePublicationTests(BasePublicationTests):
 
         # Let's register an unauthenticated principal instance for the lookup:
         principal = UnauthenticatedPrincipal('fallback')
-        ztapi.provideUtility(IFallbackUnauthenticatedPrincipal, principal)
+        component.provideUtility(principal, IFallbackUnauthenticatedPrincipal)
+
         self.publication.beforeTraversal(self.request)
         self.failUnless(self.request.principal is principal)
 
-    def testPlacefulAuth(self):
-        setup.setUpTraversal()
-        setup.setUpSiteManagerLookup()
-        principalRegistry.defineDefaultPrincipal('anonymous', '')
-
-        root = self.db.open().root()
-        app = root[ZopePublication.root_name]
-        app['f1'] = rootFolder()
-        f1 = app['f1']
-        f1['f2'] = Folder()
-        sm1 = setup.createSiteManager(f1)
-        setup.addUtility(sm1, '', IAuthentication, AuthUtility1())
-
-        f2 = f1['f2']
-        sm2 = setup.createSiteManager(f2)
-        setup.addUtility(sm2, '', IAuthentication, AuthUtility2())
-        transaction.commit()
-
-        from zope.app.container.interfaces import ISimpleReadContainer
-        from zope.app.container.traversal import ContainerTraverser
-
-        ztapi.provideView(ISimpleReadContainer, IRequest, IPublishTraverse,
-                          '', ContainerTraverser)
-
-        from zope.app.folder.interfaces import IFolder
-        from zope.security.checker import defineChecker, InterfaceChecker
-        defineChecker(Folder, InterfaceChecker(IFolder))
-
-        self.publication.beforeTraversal(self.request)
-        self.assertEqual(list(queryInteraction().participations),
-                         [self.request])
-        self.assertEqual(self.request.principal.id, 'anonymous')
-        root = self.publication.getApplication(self.request)
-        self.publication.callTraversalHooks(self.request, root)
-        self.assertEqual(self.request.principal.id, 'anonymous')
-        ob = self.publication.traverseName(self.request, root, 'f1')
-        self.publication.callTraversalHooks(self.request, ob)
-        self.assertEqual(self.request.principal.id, 'test.anonymous')
-        ob = self.publication.traverseName(self.request, ob, 'f2')
-        self.publication.afterTraversal(self.request, ob)
-        self.assertEqual(self.request.principal.id, 'test.bob')
-        self.assertEqual(list(queryInteraction().participations),
-                         [self.request])
-        self.publication.endRequest(self.request, ob)
-        self.assertEqual(queryInteraction(), None)
-
     def testTransactionCommitAfterCall(self):
         root = self.db.open().root()
         txn = transaction.get()
@@ -554,8 +531,8 @@ class ZopePublicationTests(BasePublicationTests):
         from zope.location.interfaces import ILocation
         from zope.traversing.interfaces import IPhysicallyLocatable
         from zope.traversing.interfaces import IContainmentRoot
-        ztapi.provideAdapter(ILocation, IPhysicallyLocatable,
-                             LocationPhysicallyLocatable)
+        component.provideAdapter(LocationPhysicallyLocatable,
+                                 (ILocation,), IPhysicallyLocatable)
 
         def get_txn_info():
             if hasattr(self.storage, 'iterator'):
@@ -597,13 +574,14 @@ class ZopePublicationTests(BasePublicationTests):
         self.assertEqual(txn_info['location'], expected_path)
 
     def testSiteEvents(self):
-        from zope.app.publication.interfaces import IBeforeTraverseEvent
-        from zope.app.publication.interfaces import IEndRequestEvent
+        from zope.publisher.interfaces import IEndRequestEvent
+        from zope.traversing.interfaces import IBeforeTraverseEvent
 
         set = []
         clear = []
-        ztapi.subscribe([IBeforeTraverseEvent], None, set.append)
-        ztapi.subscribe([IEndRequestEvent], None, clear.append)
+
+        component.provideHandler(set.append, (IBeforeTraverseEvent,))
+        component.provideHandler(clear.append, (IEndRequestEvent,))
 
         ob = object()
 
@@ -635,9 +613,64 @@ class ZopePublicationTests(BasePublicationTests):
         self.assertEqual(conn.db(), self.db)
 
 
+class AuthZopePublicationTests(BasePublicationTests):
+
+    def setUp(self):
+        super(AuthZopePublicationTests, self).setUp()
+        principalRegistry.defineDefaultPrincipal('anonymous', '')
+
+        root = self.db.open().root()
+        app = root[ZopePublication.root_name]
+        app['f1'] = rootFolder()
+        f1 = app['f1']
+        f1['f2'] = Folder()
+        if not ISite.providedBy(f1):
+            f1.setSiteManager(LocalSiteManager(f1))
+        sm1 = f1.getSiteManager()
+        addUtility(sm1, '', IAuthentication, AuthUtility1())
+
+        f2 = f1['f2']
+        if not ISite.providedBy(f2):
+            f2.setSiteManager(LocalSiteManager(f2))
+        sm2 = f2.getSiteManager()
+        addUtility(sm2, '', IAuthentication, AuthUtility2())
+        transaction.commit()
+
+        from zope.container.interfaces import ISimpleReadContainer
+        from zope.container.traversal import ContainerTraverser
+
+        component.provideAdapter(ContainerTraverser,
+                                 (ISimpleReadContainer, IRequest),
+                                 IPublishTraverse, name='')
+
+        from zope.site.interfaces import IFolder
+        from zope.security.checker import defineChecker, InterfaceChecker
+        defineChecker(Folder, InterfaceChecker(IFolder))
+
+    def testPlacefulAuth(self):
+        self.publication.beforeTraversal(self.request)
+        self.assertEqual(list(queryInteraction().participations),
+                         [self.request])
+        self.assertEqual(self.request.principal.id, 'anonymous')
+        root = self.publication.getApplication(self.request)
+        self.publication.callTraversalHooks(self.request, root)
+        self.assertEqual(self.request.principal.id, 'anonymous')
+        ob = self.publication.traverseName(self.request, root, 'f1')
+        self.publication.callTraversalHooks(self.request, ob)
+        self.assertEqual(self.request.principal.id, 'test.anonymous')
+        ob = self.publication.traverseName(self.request, ob, 'f2')
+        self.publication.afterTraversal(self.request, ob)
+        self.assertEqual(self.request.principal.id, 'test.bob')
+        self.assertEqual(list(queryInteraction().participations),
+                         [self.request])
+        self.publication.endRequest(self.request, ob)
+        self.assertEqual(queryInteraction(), None)
+
+
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(ZopePublicationTests),
+        unittest.makeSuite(AuthZopePublicationTests),
         unittest.makeSuite(ZopePublicationErrorHandling),
         ))
 
